<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ig" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expand</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation type="unfinished">Ndo</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Ajụjụ</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Gbachị nkịtị</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Chọta</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Ajụjụ</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Ndo</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation type="unfinished">Ndo</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question</source>
        <translation type="unfinished">Ajụjụ</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Words:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Editing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Double</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Word count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Character count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Asụsụ</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Wopu</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nke ọhụrụ</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Banye aha ọzọ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hicha</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question</source>
        <translation type="unfinished">Ajụjụ</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation type="unfinished">Ndo</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Centered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Margins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Above:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Below:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Wopu</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> pixels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Double</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Height:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Old School</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished">Nke ọhụrụ</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Hicha</translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question</source>
        <translation type="unfinished">Ajụjụ</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question</source>
        <translation type="unfinished">Ajụjụ</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Hicha</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished">Nke ọhụrụ</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question</source>
        <translation type="unfinished">Ajụjụ</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F11</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Esc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
